ElicitBuilder

Struct ElicitBuilder 

pub struct ElicitBuilder<T: Elicitation> { /* private fields */ }
Builder for one-off style overrides.

Enables ergonomic syntax: Config::with_style(ConfigStyle::Curt).elicit(&peer).await?

Implementations

Source

impl<T: Elicitation + 'static> ElicitBuilder<T>

pub async fn elicit(self, peer: Arc<Peer<RoleClient>>) -> ElicitResult<T>

Elicit the value with the pre-set style.

This is a convenience method that creates an ElicitClient, sets the style, and elicits the value in one call.

Arguments
  • peer - The RMCP peer to use for interaction
Returns

Returns the elicited value with the style applied.