pub struct DotRenderer {
pub include_primitives: bool,
pub cluster_by_pattern: bool,
}Expand description
Fields
include_primitives: boolInclude primitive and generic leaf nodes in the output.
Default: false.
cluster_by_pattern: boolGroup Survey and Select composite nodes into labelled subgraphs.
Default: true.
Implementations
Sourceimpl DotRenderer
impl DotRenderer